@@ -21,7 +21,7 @@ pub fn guess_from_debian_patch(
 
     let mut upstream_data: Vec<UpstreamDatumWithMetadata> = Vec::new();
 
-    for line in reader.lines().flatten() {
+    for line in reader.lines().map_while(Result::ok) {
         if line.starts_with("Forwarded: ") {
             let forwarded = match line.split_once(':') {
                 Some((_, url)) => url.trim(),
@@ -243,6 +243,7 @@ found in the source directory into .mo files and installs them.
     );
 }
 
+#[cfg(feature = "debian")]
 pub fn guess_from_debian_changelog(
     path: &Path,
     _settings: &GuesserSettings,
@@ -384,6 +385,7 @@ pub fn parse_debcargo_source_name(
     }
 }
 
+#[cfg(feature = "debian")]
 pub fn guess_from_debian_rules(
     path: &Path,
     _settings: &GuesserSettings,
@@ -423,6 +425,7 @@ pub fn guess_from_debian_rules(
     Ok(ret)
 }
 
+#[cfg(feature = "debian")]
 pub fn guess_from_debian_control(
     path: &Path,
     _settings: &GuesserSettings,
@@ -447,7 +450,7 @@ pub fn guess_from_debian_control(
         });
     }
 
-    if let Some(go_import_path) = source.get("XS-Go-Import-Path") {
+    if let Some(go_import_path) = source.as_deb822().get("XS-Go-Import-Path") {
         ret.push(UpstreamDatumWithMetadata {
             datum: UpstreamDatum::GoImportPath(go_import_path.to_string()),
             certainty: Some(Certainty::Certain),
@@ -535,14 +538,16 @@ pub fn guess_from_debian_control(
     Ok(ret)
 }
 
+#[cfg(feature = "debian")]
 pub fn guess_from_debian_copyright(
     path: &Path,
     _settings: &GuesserSettings,
 ) -> std::result::Result<Vec<UpstreamDatumWithMetadata>, ProviderError> {
+    use debian_copyright::lossless::{Copyright, Error};
     let mut ret = vec![];
     let text = &std::fs::read_to_string(path)?;
     let mut urls = vec![];
-    match debian_copyright::Copyright::from_str_relaxed(text) {
+    match Copyright::from_str_relaxed(text) {
         Ok((c, _)) => {
             let header = c.header().unwrap();
             if let Some(upstream_name) = header.upstream_name() {
@@ -584,7 +589,7 @@ pub fn guess_from_debian_copyright(
                 }
             }
 
-            if let Some(upstream_bugs) = header.get("X-Upstream-Bugs") {
+            if let Some(upstream_bugs) = header.as_deb822().get("X-Upstream-Bugs") {
                 ret.push(UpstreamDatumWithMetadata {
                     datum: UpstreamDatum::BugDatabase(upstream_bugs),
                     certainty: Some(Certainty::Certain),
@@ -592,7 +597,7 @@ pub fn guess_from_debian_copyright(
                 });
             }
 
-            if let Some(source_downloaded_from) = header.get("X-Source-Downloaded-From") {
+            if let Some(source_downloaded_from) = header.as_deb822().get("X-Source-Downloaded-From") {
                 if let Ok(url) = source_downloaded_from.parse::<url::Url>() {
                     urls.push(url.to_string());
                 }
@@ -616,13 +621,13 @@ pub fn guess_from_debian_copyright(
                 });
             }
         }
-        Err(debian_copyright::Error::IoError(e)) => {
+        Err(Error::IoError(e)) => {
             unreachable!("IO error: {}", e);
         }
-        Err(debian_copyright::Error::ParseError(e)) => {
+        Err(Error::ParseError(e)) => {
             return Err(ProviderError::ParseError(e.to_string()));
         }
-        Err(debian_copyright::Error::NotMachineReadable) => {
+        Err(Error::NotMachineReadable) => {
             for line in text.lines() {
                 if let Some(name) = line.strip_prefix("Upstream-Name: ") {
                     ret.push(UpstreamDatumWithMetadata {
@@ -665,6 +670,7 @@ pub fn guess_from_debian_copyright(
     Ok(ret)
 }
 
+#[cfg(feature = "debian")]
 pub fn guess_from_debian_watch(
     path: &Path,
     _settings: &GuesserSettings,
@@ -720,48 +726,7 @@ pub fn guess_from_debian_watch(
     Ok(ret)
 }
 
-#[cfg(test)]
-mod watch_tests {
-    use super::*;
-
-    #[test]
-    fn test_empty() {
-        let td = tempfile::tempdir().unwrap();
-        let path = td.path().join("watch");
-        std::fs::write(
-            &path,
-            r#"
-# Blah
-"#,
-        )
-        .unwrap();
-        assert!(guess_from_debian_watch(&path, &GuesserSettings::default())
-            .unwrap()
-            .is_empty());
-    }
-
-    #[test]
-    fn test_simple() {
-        let td = tempfile::tempdir().unwrap();
-        let path = td.path().join("watch");
-        std::fs::write(
-            &path,
-            r#"version=4
-https://github.com/jelmer/dulwich/tags/dulwich-(.*).tar.gz
-"#,
-        )
-        .unwrap();
-        assert_eq!(
-            vec![UpstreamDatumWithMetadata {
-                datum: UpstreamDatum::Repository("https://github.com/jelmer/dulwich".to_string()),
-                certainty: Some(Certainty::Confident),
-                origin: Some(path.clone().into())
-            }],
-            guess_from_debian_watch(&path, &GuesserSettings::default()).unwrap()
-        );
-    }
-}
-
+#[cfg(feature = "debian")]
 pub fn debian_is_native(path: &Path) -> std::io::Result<Option<bool>> {
     let format_file_path = path.join("source/format");
     match File::open(format_file_path) {
@@ -789,3 +754,47 @@ pub fn debian_is_native(path: &Path) -> std::io::Result<Option<bool>> {
 
     Ok(None)
 }
+
+#[cfg(test)]
+mod watch_tests {
+    use super::*;
+
+    #[cfg(feature = "debian")]
+    #[test]
+    fn test_empty() {
+        let td = tempfile::tempdir().unwrap();
+        let path = td.path().join("watch");
+        std::fs::write(
+            &path,
+            r#"
+# Blah
+"#,
+        )
+        .unwrap();
+        assert!(guess_from_debian_watch(&path, &GuesserSettings::default())
+            .unwrap()
+            .is_empty());
+    }
+
+    #[cfg(feature = "debian")]
+    #[test]
+    fn test_simple() {
+        let td = tempfile::tempdir().unwrap();
+        let path = td.path().join("watch");
+        std::fs::write(
+            &path,
+            r#"version=4
+https://github.com/jelmer/dulwich/tags/dulwich-(.*).tar.gz
+"#,
+        )
+        .unwrap();
+        assert_eq!(
+            vec![UpstreamDatumWithMetadata {
+                datum: UpstreamDatum::Repository("https://github.com/jelmer/dulwich".to_string()),
+                certainty: Some(Certainty::Confident),
+                origin: Some(path.clone().into())
+            }],
+            guess_from_debian_watch(&path, &GuesserSettings::default()).unwrap()
+        );
+    }
+}
