@@ -1,7 +1,9 @@
 use crate::{
     Certainty, GuesserSettings, Origin, ProviderError, UpstreamDatum, UpstreamDatumWithMetadata,
+    UpstreamMetadata,
 };
 use lazy_regex::regex;
+use serde::Deserialize;
 
 use std::collections::HashMap;
 use std::fs::File;
@@ -409,7 +411,7 @@ pub fn guess_from_makefile_pl(
     let name_regex = regex!("name '([^'\"]+)';$");
     let repository_regex = regex!("repository '([^'\"]+)';$");
 
-    for line in reader.lines().flatten() {
+    for line in reader.lines().map_while(Result::ok) {
         if let Some(captures) = name_regex.captures(&line) {
             dist_name = Some(captures.get(1).unwrap().as_str().to_owned());
             let name = dist_name.as_ref().unwrap().to_owned();
@@ -435,3 +437,121 @@ pub fn guess_from_makefile_pl(
 
     Ok(results)
 }
+
+#[derive(Deserialize)]
+pub struct Module {
+    pub version_numified: f64,
+    pub version: String,
+    pub authorized: bool,
+    pub name: String,
+    pub indexed: bool,
+}
+
+#[derive(Deserialize)]
+pub struct Stat {
+    pub uid: isize,
+    pub mtime: isize,
+    pub size: isize,
+    pub mode: isize,
+    pub gid: isize,
+}
+
+#[derive(Deserialize)]
+pub struct CpanModule {
+    pub maturity: String,
+    pub release: String,
+    pub author: String,
+    pub slop: isize,
+    pub download_url: url::Url,
+    pub module: Vec<Module>,
+    pub pod_lines: Vec<String>,
+    pub version: String,
+    pub deprecated: bool,
+    pub level: isize,
+    pub mime: String,
+    pub date: String,
+    pub path: String,
+    pub distribution: String,
+    pub pod: String,
+    pub name: String,
+    pub sloc: isize,
+    pub stat: Stat,
+    pub version_numified: f64,
+    pub binary: bool,
+    pub id: String,
+    pub directory: bool,
+    pub indexed: bool,
+    pub authorized: bool,
+}
+
+impl TryFrom<CpanModule> for UpstreamMetadata {
+    type Error = crate::ProviderError;
+
+    fn try_from(value: CpanModule) -> Result<Self, Self::Error> {
+        let mut metadata = UpstreamMetadata::default();
+
+        metadata.insert(UpstreamDatumWithMetadata {
+            datum: UpstreamDatum::Name(value.name),
+            certainty: Some(Certainty::Certain),
+            origin: None,
+        });
+
+        metadata.insert(UpstreamDatumWithMetadata {
+            datum: UpstreamDatum::Version(value.version),
+            certainty: Some(Certainty::Certain),
+            origin: None,
+        });
+
+        metadata.insert(UpstreamDatumWithMetadata {
+            datum: UpstreamDatum::Homepage(value.download_url.to_string()),
+            certainty: Some(Certainty::Certain),
+            origin: None,
+        });
+
+        metadata.insert(UpstreamDatumWithMetadata {
+            datum: UpstreamDatum::Download(value.download_url.to_string()),
+            certainty: Some(Certainty::Certain),
+            origin: None,
+        });
+
+        metadata.insert(UpstreamDatumWithMetadata {
+            datum: UpstreamDatum::Author(vec![crate::Person::from(value.author.as_str())]),
+            certainty: Some(Certainty::Certain),
+            origin: None,
+        });
+
+        Ok(metadata)
+    }
+}
+
+pub fn load_cpan_data(module: &str) -> Result<Option<CpanModule>, crate::ProviderError> {
+    let url = format!("https://fastapi.metacpan.org/v1/release/{}", module)
+        .parse()
+        .unwrap();
+
+    let data = crate::load_json_url(&url, None)?;
+
+    Ok(Some(serde_json::from_value(data).unwrap()))
+}
+
+pub fn remote_cpan_data(module: &str) -> Result<UpstreamMetadata, crate::ProviderError> {
+    let data = load_cpan_data(module)?;
+
+    match data {
+        Some(data) => data.try_into(),
+        None => Ok(UpstreamMetadata::default()),
+    }
+}
+
+#[cfg(test)]
+mod tests {
+    use super::*;
+
+    #[test]
+    fn test_load_from_json() {
+        let text = include_str!("../testdata/cpan.json");
+        let cpan_module: CpanModule = serde_json::from_str(text).unwrap();
+
+        assert_eq!("Parse-Pidl-0.02", cpan_module.release);
+    }
+}
